// Date Picker List
html:not([data-scale]) .am-list-body::before,
html:not([data-scale]) .am-list-body::after,
html:not([data-scale]) .am-list-item:not(:last-child) .am-list-line::after {
    border: none;
    content: none;
}

.ant-checkbox-inner {
    min-width: 24px;
    min-height: 24px;
}

.ant-tabs-tab {
    margin: 0 32px 0 0;
}
