@import "src/variables";

%primary-button {
  border-width: 0;
  display: flex;
  align-items: center;
  justify-content: center;
  text-align: center;
  height: 100%;
  color: $primary-color;
  background: $primary-color-translucent;
  border-radius: $button-border-radius;
  min-height: $button-height;
  height: $button-height;
  font-weight: $semi-bold;
  padding: 0 16px;
  white-space: nowrap;
  font-size: 1rem;

  &[disabled] {
    background: $disabled-background-color;
    color: $disabled-color;
  }
}

%primary-tag {
  @extend %primary-button;
  border-radius: $border-radius;
  background: $primary-color;
  color: #fff;
  min-height: 30px;
  height: 30px;
  text-transform: uppercase;
  padding: 0 8px;
  font-size: calc(1rem - 2px);
  font-weight: $bold;
  letter-spacing: 0.5px;
}

%select {
  border: 1px solid $border-color;
  border-radius: 4px;
  padding-right: 12px;
  line-height: 44px;
  height: 44px;

  > select {
    width: 100%;
    height: 100%;
    background: transparent;
    border: none;
    padding-left: 12px;
  }
}
