nz-spin {
  display: flex;
  flex-direction: column;
  flex-grow: 1;
  min-height: 0;

  > .ant-spin-container {
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    min-height: 0;
  }
}
